pub fn run_system_cached_with<I, M, S>(
system: S,
input: I::Inner<'static>,
) -> impl Commandwhere
I: SystemInput<Inner<'static>: Send> + Send + 'static,
M: 'static,
S: IntoSystem<I, (), M> + Send + 'static,Expand description
A Command that runs the given system with the given input value,
caching its SystemId in a CachedSystemId resource.
To use the supplied input, the system should have a SystemInput as the first parameter.